"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbstractTemplatedJCL = void 0;
const imperative_1 = require("@zowe/imperative");
const CoreUtils_1 = require("./CoreUtils");
class AbstractTemplatedJCL {
    /**
     *
     * @param jobCardFile - file containing a job card which will be prepended to the job
     * @param  substitutionValues -
     * @param  templateFile - override the default JCL template with a file
     */
    getJcl(jobCardFile, substitutionValues, templateFile) {
        let jcl = imperative_1.IO.readFileSync(jobCardFile).toString();
        if (!/\r?\nZ/.test(jcl)) {
            // add a newline to the end of the jcl if there is none
            jcl += "\r\n";
        }
        if (templateFile != null) {
            // we
            jcl += imperative_1.IO.readFileSync(templateFile).toString();
        }
        else {
            jcl += this.DEFAULT_TEMPLATE;
        }
        return imperative_1.TextUtils.renderWithMustache(CoreUtils_1.CoreUtils.addCarriageReturns(jcl), substitutionValues);
    }
    get log() {
        return imperative_1.Logger.getAppLogger();
    }
}
exports.AbstractTemplatedJCL = AbstractTemplatedJCL;
//# sourceMappingURL=AbstractTemplatedJCL.js.map