"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConnectionString = void 0;
const util_1 = require("util");
/**
 * DB2 server APIs
 * @class DB2
 * @export
 */
class ConnectionString {
    /**
     * Build the ODBC connection string from a Session object
     * @param {IDB2Session} session Connection string values
     * @returns {string}
     * @memberof ConnectionString
     */
    static buildFromSession(session) {
        let connectionString = "DRIVER={DB2 ODBC Driver};";
        if (!util_1.isNullOrUndefined(session.database)) {
            connectionString += `DATABASE=${session.database};`;
        }
        if (!util_1.isNullOrUndefined(session.hostname)) {
            connectionString += `HOSTNAME=${session.hostname};`;
        }
        if (!util_1.isNullOrUndefined(session.port)) {
            connectionString += `PORT=${session.port};PROTOCOL=TCPIP;`;
        }
        if (!util_1.isNullOrUndefined(session.user)) {
            connectionString += `UID=${session.user};`;
        }
        if (!util_1.isNullOrUndefined(session.password)) {
            connectionString += `PWD=${session.password};`;
        }
        if (!util_1.isNullOrUndefined(session.sslFile)) {
            connectionString += `Security=SSL;SSLServerCertificate=${session.sslFile};`;
        }
        return connectionString;
    }
    /**
     * Build the ODBC connection string
     * @param {string} hostname The name or IP address of the server to connect to
     * @param {number} port The port number where the server is listening
     * @param {string} user The user ID
     * @param {string} password The user's password
     * @param {string} database The database name to use
     * @param {string} sslFile The path to a SSL Certificate file or CA signed certificate
     * @returns {string}
     */
    static build(hostname, port, user, password, database, sslFile) {
        let connectionString = "DRIVER={DB2 ODBC Driver};";
        if (!util_1.isNullOrUndefined(database)) {
            connectionString += `DATABASE=${database};`;
        }
        if (!util_1.isNullOrUndefined(hostname)) {
            connectionString += `HOSTNAME=${hostname};`;
        }
        if (!util_1.isNullOrUndefined(port)) {
            connectionString += `PORT=${port};PROTOCOL=TCPIP;`;
        }
        if (!util_1.isNullOrUndefined(user)) {
            connectionString += `UID=${user};`;
        }
        if (!util_1.isNullOrUndefined(password)) {
            connectionString += `PWD=${password};`;
        }
        if (!util_1.isNullOrUndefined(sslFile)) {
            connectionString += `Security=SSL;SSLServerCertificate=${sslFile};`;
        }
        return connectionString;
    }
}
exports.ConnectionString = ConnectionString;
//# sourceMappingURL=ConnectionString.js.map