/**
 * Interface representing API response from IMS's web interface, parsed from XML to a javascript object
 * using the xml2js package.
 */
export interface IIMSApiResponse {
    /**
     * A list of objects returned from the API
     */
    data: any;
    /**
     * Error or success messages encountered during the execution of the request
     * A map that represents messages that are returned from OM after submitting the command.
     *
     */
    messages: {
        /**
         * The key is either the IMS member or OM that returned the message
         */
        [key: string]: {
            /**
             * Reason code text
             */
            rsntxt: string;
            /**
             * Message from OM. Usually returned only when there is an error
             */
            message: string;
            /**
             * Return code
             */
            rc: string;
            /**
             * The command executed
             */
            command: string;
            /**
             * Reason code
             */
            rsn: string;
        };
    };
}
