"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
const PluginConstants_1 = require("./api/rest/constants/PluginConstants");
const MQSessionUtils_1 = require("./cli/MQSessionUtils");
const config = {
    commandModuleGlobs: ["**/cli/*/*.definition!(.d).*s"],
    rootCommandDescription: PluginConstants_1.PluginConstants.PLUGIN_DESCRIPTION,
    productDisplayName: PluginConstants_1.PluginConstants.PLUGIN_NAME,
    name: PluginConstants_1.PluginConstants.PLUGIN_GROUP_NAME,
    pluginHealthCheck: __dirname + "/healthCheck.Handler",
    // apimlConnLookup: [
    //     {
    //         apiId: "place_the_mq_apiId_here",
    //         gatewayUrl: "api/v1",
    //         connProfType: "mq"
    //     }
    // ],
    profiles: [
        {
            type: "mq",
            schema: {
                type: "object",
                title: "CLI profile for MQ",
                description: "An MQREST profile is required to issue commands in the MQ command group that interacts with MQSC. " +
                    "The mq profile contains your host, port, user name, and password for the IBM MQ System Console interface",
                properties: {
                    host: {
                        type: "string",
                        optionDefinition: MQSessionUtils_1.MqSessionUtils.MQ_OPTION_HOST,
                    },
                    port: {
                        type: "number",
                        optionDefinition: MQSessionUtils_1.MqSessionUtils.MQ_OPTION_PORT,
                    },
                    user: {
                        type: "string",
                        optionDefinition: MQSessionUtils_1.MqSessionUtils.MQ_OPTION_USER,
                        secure: true
                    },
                    password: {
                        type: "string",
                        optionDefinition: MQSessionUtils_1.MqSessionUtils.MQ_OPTION_PASSWORD,
                        secure: true
                    },
                    rejectUnauthorized: {
                        type: "boolean",
                        optionDefinition: MQSessionUtils_1.MqSessionUtils.MQ_OPTION_REJECT_UNAUTHORIZED
                    },
                    protocol: {
                        type: "string",
                        optionDefinition: MQSessionUtils_1.MqSessionUtils.MQ_OPTION_PROTOCOL
                    }
                },
                required: [],
            },
            createProfileExamples: [
                {
                    options: "mq --host mq123 --port 1234 --user ibmuser --password myp4ss",
                    description: "Create an MQ profile named 'mqprofile' to connect to MQ at host zos123 and port 1234"
                }
            ]
        }
    ]
};
module.exports = config;
//# sourceMappingURL=imperative.js.map